@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 
 QVector<PimCommon::defaultTemplate> ContactDefaultTemplate::contactTemplates()
 {
-    return QVector<PimCommon::defaultTemplate>();
+    return {};
     /*
     PimCommon::defaultTemplate tmp;
     //TODO
