@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-
 using namespace GrantleeThemeEditor;
 
 ThemeSession::ThemeSession(const QString &projectDirectory, const QString &themeTypeName)
@@ -19,9 +18,7 @@ ThemeSession::ThemeSession(const QString &projectDirectory, const QString &theme
 {
 }
 
-ThemeSession::~ThemeSession()
-{
-}
+ThemeSession::~ThemeSession() = default;
 
 QString ThemeSession::projectDirectory() const
 {
